pub enum OsdpCommand {
Led(OsdpCommandLed),
Buzzer(OsdpCommandBuzzer),
Text(OsdpCommandText),
Output(OsdpCommandOutput),
ComSet(OsdpComSet),
ComSetDone(OsdpComSet),
KeySet(OsdpCommandKeyset),
Mfg(OsdpCommandMfg),
FileTx(OsdpCommandFileTx),
Status(OsdpStatusReport),
}Expand description
CP interacts with and controls PDs by sending commands to it. The commands in this enum are specified by OSDP specification.
Variants
Led(OsdpCommandLed)
Command to control the behavior of it’s on-board LEDs
Buzzer(OsdpCommandBuzzer)
Command to control the behavior of a buzzer in the PD
Text(OsdpCommandText)
Command to manipulate the on-board display unit (Can be LED, LCD, 7-Segment, etc.,) on the PD
Output(OsdpCommandOutput)
Command to control digital output exposed by the PD
ComSet(OsdpComSet)
Command to request setting the communication parameters for the PD.
ComSetDone(OsdpComSet)
Set communication parameter completed. The effects of this command is expected to be be stored in PD’s non-volatile memory as the CP will expect the PD to be in this state moving forward
KeySet(OsdpCommandKeyset)
Command to set secure channel keys to the PD
Mfg(OsdpCommandMfg)
Command to to act as a wrapper for manufacturer specific commands
FileTx(OsdpCommandFileTx)
Command to kick-off a file transfer to the PD
Status(OsdpStatusReport)
Command to query status from the PD