pub enum PdCapability {
Show 16 variants
ContactStatusMonitoring(PdCapEntity),
OutputControl(PdCapEntity),
CardDataFormat(PdCapEntity),
LedControl(PdCapEntity),
AudibleOutput(PdCapEntity),
TextOutput(PdCapEntity),
TimeKeeping(PdCapEntity),
CheckCharacterSupport(PdCapEntity),
CommunicationSecurity(PdCapEntity),
ReceiveBufferSize(PdCapEntity),
LargestCombinedMessage(PdCapEntity),
SmartCardSupport(PdCapEntity),
Readers(PdCapEntity),
Biometrics(PdCapEntity),
SecurePinEntry(PdCapEntity),
OsdpVersion(PdCapEntity),
}Expand description
OSDP defined PD capabilities. PDs expose/advertise features they support to the CP by means of “capabilities”.
Variants
ContactStatusMonitoring(PdCapEntity)
This function indicates the ability to monitor the status of a switch using a two-wire electrical connection between the PD and the switch. The on/off position of the switch indicates the state of an external device.
The PD may simply resolve all circuit states to an open/closed status, or it may implement supervision of the monitoring circuit. A supervised circuit is able to indicate circuit fault status in addition to open/closed status.
OutputControl(PdCapEntity)
This function provides a switched output, typically in the form of a relay. The Output has two states: active or inactive. The Control Panel (CP) can directly set the Output’s state, or, if the PD supports timed operations, the CP can specify a time period for the activation of the Output.
CardDataFormat(PdCapEntity)
This capability indicates the form of the card data is presented to the Control Panel.
LedControl(PdCapEntity)
This capability indicates the presence of and type of LEDs.
AudibleOutput(PdCapEntity)
This capability indicates the presence of and type of an audible annunciator (buzzer or similar tone generator).
TextOutput(PdCapEntity)
This capability indicates that the PD supports a text display emulating character-based display terminals.
TimeKeeping(PdCapEntity)
This capability indicates that the type of date and time awareness or time keeping ability of the PD.
CheckCharacterSupport(PdCapEntity)
All PDs must be able to support the checksum mode. This capability indicates if the PD is capable of supporting CRC mode.
CommunicationSecurity(PdCapEntity)
This capability indicates the extent to which the PD supports communication security (Secure Channel Communication)
ReceiveBufferSize(PdCapEntity)
This capability indicates the maximum size single message the PD can receive.
LargestCombinedMessage(PdCapEntity)
This capability indicates the maximum size multi-part message which the PD can handle.
SmartCardSupport(PdCapEntity)
This capability indicates whether the PD supports the transparent mode used for communicating directly with a smart card.
Readers(PdCapEntity)
This capability indicates the number of credential reader devices present. Compliance levels are bit fields to be assigned as needed.
Biometrics(PdCapEntity)
This capability indicates the ability of the reader to handle biometric input.
SecurePinEntry(PdCapEntity)
This capability indicates if the reader is capable of supporting Secure Pin Entry (SPE) for smart cards
OsdpVersion(PdCapEntity)
This capability indicates the version of OSDP the PD supports Compliance Levels: 0 - Unspecified 1 - IEC 60839-11-5 2 - SIA OSDP 2.2